@@ -48,48 +48,48 @@
  * debugSDNA. This int can be set to 0 (no output) to some int. Higher
  * numbers give more output.
  * */
- 
-	
+
 #ifdef __cplusplus
-extern "C" {
+extern "C"
+{
 #endif
- 
+
 #if defined(_WIN32) && !defined(FREE_WINDOWS)
 
-/* The __intXX are built-in types of the visual complier! So we don't
+	/* The __intXX are built-in types of the visual complier! So we don't
  * need to include anything else here. */
 
-typedef signed __int8  int8_t;
-typedef signed __int16 int16_t;
-typedef signed __int32 int32_t;
-typedef signed __int64 int64_t;
+	typedef signed __int8 int8_t;
+	typedef signed __int16 int16_t;
+	typedef signed __int32 int32_t;
+	typedef signed __int64 int64_t;
 
-typedef unsigned __int8  uint8_t;
-typedef unsigned __int16 uint16_t;
-typedef unsigned __int32 uint32_t;
-typedef unsigned __int64 uint64_t;
+	typedef unsigned __int8 uint8_t;
+	typedef unsigned __int16 uint16_t;
+	typedef unsigned __int32 uint32_t;
+	typedef unsigned __int64 uint64_t;
 
 #ifndef _INTPTR_T_DEFINED
-	#ifdef _WIN64
+#ifdef _WIN64
 	typedef __int64 btintptr_t;
-	#else
+#else
 	typedef long btintptr_t;
-	#endif
-	
+#endif
+
 #else
 	typedef intptr_t btintptr_t;
 #endif
 
-
-
 #elif defined(__linux__) || defined(__NetBSD__)
 
-	/* Linux-i386, Linux-Alpha, Linux-ppc */
+/* Linux-i386, Linux-Alpha, Linux-ppc */
 #include <stdint.h>
+typedef intptr_t btintptr_t;
 
-#elif defined (__APPLE__)
+#elif defined(__APPLE__)
 
 #include <inttypes.h>
+typedef intptr_t btintptr_t;
 
 #elif defined(FREE_WINDOWS)
 
@@ -97,7 +97,7 @@ typedef unsigned __int64 uint64_t;
 
 #else
 
-	/* FreeBSD, Irix, Solaris */
+/* FreeBSD, Irix, Solaris */
 #include <sys/types.h>
 
 #endif /* ifdef platform for types */
@@ -106,7 +106,6 @@ typedef unsigned __int64 uint64_t;
 }
 #endif
 
-
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -132,6 +131,7 @@ typedef unsigned __int64 uint64_t;
 #include "BulletCollision/CollisionShapes/btConeShape.h"
 #include "BulletCollision/CollisionShapes/btCapsuleShape.h"
 #include "BulletCollision/CollisionShapes/btTriangleInfoMap.h"
+#include "BulletCollision/NarrowPhaseCollision/btPersistentManifold.h"
 #include "BulletCollision/Gimpact/btGImpactShape.h"
 #include "BulletCollision/CollisionDispatch/btCollisionObject.h"
 #include "BulletDynamics/ConstraintSolver/btTypedConstraint.h"
@@ -149,6 +149,7 @@ typedef unsigned __int64 uint64_t;
 #include "BulletDynamics/Dynamics/btRigidBody.h"
 #include "BulletSoftBody/btSoftBodyData.h"
 #include "BulletDynamics/Featherstone/btMultiBody.h"
+#include "BulletDynamics/Featherstone/btMultiBodyLinkCollider.h"
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -180,6 +181,7 @@ char *includefiles[] = {
 	"../../../src/BulletCollision/CollisionShapes/btConeShape.h",
 	"../../../src/BulletCollision/CollisionShapes/btCapsuleShape.h",
 	"../../../src/BulletCollision/CollisionShapes/btTriangleInfoMap.h",
+	"../../../src/BulletCollision/NarrowPhaseCollision/btPersistentManifold.h",
 	"../../../src/BulletCollision/Gimpact/btGImpactShape.h",
 	"../../../src/BulletCollision/CollisionShapes/btConvexHullShape.h",
 	"../../../src/BulletCollision/CollisionDispatch/btCollisionObject.h",
@@ -195,29 +197,29 @@ char *includefiles[] = {
 	"../../../src/BulletDynamics/ConstraintSolver/btGeneric6DofSpring2Constraint.h",
 	"../../../src/BulletDynamics/ConstraintSolver/btSliderConstraint.h",
 	"../../../src/BulletDynamics/ConstraintSolver/btGearConstraint.h",
-	
+
 	"../../../src/BulletSoftBody/btSoftBodyData.h",
 	"../../../src/BulletDynamics/Featherstone/btMultiBody.h",
+	"../../../src/BulletDynamics/Featherstone/btMultiBodyLinkCollider.h",
 	// empty string to indicate end of includefiles
-	""
-};
+	""};
 
-void* malloc_and_setzero(int numbytes)
+void *malloc_and_setzero(int numbytes)
 {
-	char* buf = (char*)malloc(numbytes);
-	memset(buf,0,numbytes);
+	char *buf = (char *)malloc(numbytes);
+	memset(buf, 0, numbytes);
 	return buf;
 }
 
-int maxdata= 500000, maxnr= 50000;
-int nr_names=0;
-int nr_types=0;
-int nr_structs=0;
-char **names, *namedata;		/* at adress names[a] is string a */
-char **types, *typedata;		/* at adress types[a] is string a */
-short *typelens;				/* at typelens[a] is de length of type a */
-short *alphalens;			    /* contains sizes as they are calculated on the DEC Alpha (64 bits) */
-short **structs, *structdata;	/* at sp= structs[a] is the first adress of a struct definition
+int maxdata = 500000, maxnr = 50000;
+int nr_names = 0;
+int nr_types = 0;
+int nr_structs = 0;
+char **names, *namedata;      /* at adress names[a] is string a */
+char **types, *typedata;      /* at adress types[a] is string a */
+short *typelens;              /* at typelens[a] is de length of type a */
+short *alphalens;             /* contains sizes as they are calculated on the DEC Alpha (64 bits) */
+short **structs, *structdata; /* at sp= structs[a] is the first adress of a struct definition
 								   sp[0] is type number
 								   sp[1] is amount of elements
 								   sp[2] sp[3] is typenr,  namenr (etc) */
@@ -259,22 +261,22 @@ int preprocess_include(char *maindata, int len);
 
 /**
  * Scan this file for serializable types.
- */ 
+ */
 int convert_include(char *filename);
 
 /**
  * Determine how many bytes are needed for an array.
- */ 
+ */
 int arraysize(char *astr, int len);
 
 /**
  * Determine how many bytes are needed for each struct.
- */ 
+ */
 static int calculate_structlens(int);
 
 /**
  * Construct the DNA.c file
- */ 
+ */
 void dna_write(FILE *file, void *pntr, int size);
 
 /**
@@ -282,8 +284,6 @@ void dna_write(FILE *file, void *pntr, int size);
  */
 void printStructLenghts(void);
 
-
-
 /* ************************************************************************** */
 /* Implementation                                                             */
 /* ************************************************************************** */
@@ -294,37 +294,44 @@ int add_type(char *str, int len)
 {
 	int nr;
 	char *cp;
-	
-	if(str[0]==0) return -1;
-	
+
+	if (str[0] == 0) return -1;
+
 	/* search through type array */
-	for(nr=0; nr<nr_types; nr++) {
-		if(strcmp(str, types[nr])==0) {
-			if (len) {
-				typelens[nr]= len;
+	for (nr = 0; nr < nr_types; nr++)
+	{
+		if (strcmp(str, types[nr]) == 0)
+		{
+			if (len)
+			{
+				typelens[nr] = len;
 				alphalens[nr] = len;
 			}
 			return nr;
 		}
 	}
-	
+
 	/* append new type */
-	if(nr_types==0) cp= typedata;
-	else {
-		cp= types[nr_types-1]+strlen(types[nr_types-1])+1;
+	if (nr_types == 0)
+		cp = typedata;
+	else
+	{
+		cp = types[nr_types - 1] + strlen(types[nr_types - 1]) + 1;
 	}
 	strcpy(cp, str);
-	types[nr_types]= cp;
-	typelens[nr_types]= len;
-	alphalens[nr_types]= len;
-	
-	if(nr_types>=maxnr) {
+	types[nr_types] = cp;
+	typelens[nr_types] = len;
+	alphalens[nr_types] = len;
+
+	if (nr_types >= maxnr)
+	{
 		printf("too many types\n");
-		return nr_types-1;;
+		return nr_types - 1;
+		;
 	}
 	nr_types++;
-	
-	return nr_types-1;
+
+	return nr_types - 1;
 }
 
 /**
@@ -343,20 +350,22 @@ int add_name(char *str)
 	char *name;
 
 	additional_slen_offset = 0;
-	
-	if((str[0]==0) /*  || (str[1]==0) */) return -1;
 
-	if (str[0] == '(' && str[1] == '*') {
+	if ((str[0] == 0) /*  || (str[1]==0) */) return -1;
+
+	if (str[0] == '(' && str[1] == '*')
+	{
 		if (debugSDNA > 3) printf("\t\t\t\t*** Function pointer found\n");
 		/* functionpointer: transform the type (sometimes) */
 		i = 0;
 		j = 0;
 
-		while (str[i] != ')') {
+		while (str[i] != ')')
+		{
 			buf[i] = str[i];
 			i++;
 		}
-		
+
 		/* Another number we need is the extra slen offset. This extra
 		 * offset is the overshoot after a space. If there is no
 		 * space, no overshoot should be calculated. */
@@ -365,30 +374,37 @@ int add_name(char *str)
 		if (debugSDNA > 3) printf("first brace after offset %d\n", i);
 
 		j++; /* j beyond closing brace ? */
-		while ((str[j] != 0) && (str[j] != ')' )) {
+		while ((str[j] != 0) && (str[j] != ')'))
+		{
 			if (debugSDNA > 3) printf("seen %c ( %d) \n", str[j], str[j]);
 			j++;
 		}
-		if (debugSDNA > 3) printf("seen %c ( %d) \n", str[j], str[j]); 
-		if (debugSDNA > 3) printf("special after offset %d\n", j); 
-				
-		if (str[j] == 0 ) {
-			if (debugSDNA > 3) printf("offsetting for space\n"); 
+		if (debugSDNA > 3) printf("seen %c ( %d) \n", str[j], str[j]);
+		if (debugSDNA > 3) printf("special after offset %d\n", j);
+
+		if (str[j] == 0)
+		{
+			if (debugSDNA > 3) printf("offsetting for space\n");
 			/* get additional offset */
 			k = 0;
-			while (str[j] != ')') {
+			while (str[j] != ')')
+			{
 				j++;
 				k++;
 			}
 			if (debugSDNA > 3) printf("extra offset %d\n", k);
 			additional_slen_offset = k;
-		} else if (str[j] == ')' ) {
+		}
+		else if (str[j] == ')')
+		{
 			if (debugSDNA > 3) printf("offsetting for brace\n");
 			; /* don't get extra offset */
-		} else {
+		}
+		else
+		{
 			printf("Error during tokening function pointer argument list\n");
 		}
-				
+
 		/*
 		 * Put )(void) at the end? Maybe )(). Should check this with
          * old sdna. Actually, sometimes )(), sometimes )(void...)
@@ -402,53 +418,62 @@ int add_name(char *str)
 		 *
 		 * */
 		buf[i] = 0;
-		if (debugSDNA > 3) printf("Name before chomping: %s\n", buf); 
-		if ( (strncmp(buf,"(*headdraw", 10) == 0)
-			|| (strncmp(buf,"(*windraw", 9) == 0) ) {
+		if (debugSDNA > 3) printf("Name before chomping: %s\n", buf);
+		if ((strncmp(buf, "(*headdraw", 10) == 0) || (strncmp(buf, "(*windraw", 9) == 0))
+		{
 			buf[i] = ')';
-			buf[i+1] = '(';
-			buf[i+2] = 'v'; 
-			buf[i+3] = 'o';
-			buf[i+4] = 'i';
-			buf[i+5] = 'd';
-			buf[i+6] = ')';
-			buf[i+7] = 0;
-		} else {
+			buf[i + 1] = '(';
+			buf[i + 2] = 'v';
+			buf[i + 3] = 'o';
+			buf[i + 4] = 'i';
+			buf[i + 5] = 'd';
+			buf[i + 6] = ')';
+			buf[i + 7] = 0;
+		}
+		else
+		{
 			buf[i] = ')';
-			buf[i+1] = '(';
-			buf[i+2] = ')';
-			buf[i+3] = 0;
+			buf[i + 1] = '(';
+			buf[i + 2] = ')';
+			buf[i + 3] = 0;
 		}
 		/* now precede with buf*/
-		if (debugSDNA > 3)  printf("\t\t\t\t\tProposing fp name %s\n", buf);
+		if (debugSDNA > 3) printf("\t\t\t\t\tProposing fp name %s\n", buf);
 		name = buf;
-	} else {
+	}
+	else
+	{
 		/* normal field: old code */
 		name = str;
 	}
-	
+
 	/* search name array */
-	for(nr=0; nr<nr_names; nr++) {
-		if(strcmp(name, names[nr])==0) {
+	for (nr = 0; nr < nr_names; nr++)
+	{
+		if (strcmp(name, names[nr]) == 0)
+		{
 			return nr;
 		}
 	}
-	
+
 	/* append new type */
-	if(nr_names==0) cp= namedata;
-	else {
-		cp= names[nr_names-1]+strlen(names[nr_names-1])+1;
+	if (nr_names == 0)
+		cp = namedata;
+	else
+	{
+		cp = names[nr_names - 1] + strlen(names[nr_names - 1]) + 1;
 	}
 	strcpy(cp, name);
-	names[nr_names]= cp;
-	
-	if(nr_names>=maxnr) {
+	names[nr_names] = cp;
+
+	if (nr_names >= maxnr)
+	{
 		printf("too many names\n");
-		return nr_names-1;
+		return nr_names - 1;
 	}
 	nr_names++;
-	
-	return nr_names-1;
+
+	return nr_names - 1;
 }
 
 short *add_struct(int namecode)
@@ -456,24 +481,27 @@ short *add_struct(int namecode)
 	int len;
 	short *sp;
 
-	if(nr_structs==0) {
-		structs[0]= structdata;
+	if (nr_structs == 0)
+	{
+		structs[0] = structdata;
 	}
-	else {
-		sp= structs[nr_structs-1];
-		len= sp[1];
-		structs[nr_structs]= sp+ 2*len+2;
+	else
+	{
+		sp = structs[nr_structs - 1];
+		len = sp[1];
+		structs[nr_structs] = sp + 2 * len + 2;
 	}
-	
-	sp= structs[nr_structs];
-	sp[0]= namecode;
-	
-	if(nr_structs>=maxnr) {
+
+	sp = structs[nr_structs];
+	sp[0] = namecode;
+
+	if (nr_structs >= maxnr)
+	{
 		printf("too many structs\n");
 		return sp;
 	}
 	nr_structs++;
-	
+
 	return sp;
 }
 
@@ -481,55 +509,64 @@ int preprocess_include(char *maindata, int len)
 {
 	int a, newlen, comment = 0;
 	char *cp, *temp, *md;
-	
-	temp= (char*) malloc_and_setzero(len);
+
+	temp = (char *)malloc_and_setzero(len);
 	memcpy(temp, maindata, len);
-	
+
 	// remove all c++ comments
 	/* replace all enters/tabs/etc with spaces */
-	cp= temp;
-	a= len;
+	cp = temp;
+	a = len;
 	comment = 0;
-	while(a--) {
-		if(cp[0]=='/' && cp[1]=='/') {
+	while (a--)
+	{
+		if (cp[0] == '/' && cp[1] == '/')
+		{
 			comment = 1;
-		} else if (*cp<32) {
+		}
+		else if (*cp < 32)
+		{
 			comment = 0;
 		}
-		if (comment || *cp<32 || *cp>128 ) *cp= 32;
+		if (comment || *cp < 32 || *cp > 128) *cp = 32;
 		cp++;
 	}
-	
 
 	/* data from temp copy to maindata, remove comments and double spaces */
-	cp= temp;
-	md= maindata;
-	newlen= 0;
-	comment= 0;
-	a= len;
-	while(a--) {
-		
-		if(cp[0]=='/' && cp[1]=='*') {
-			comment= 1;
-			cp[0]=cp[1]= 32;
+	cp = temp;
+	md = maindata;
+	newlen = 0;
+	comment = 0;
+	a = len;
+	while (a--)
+	{
+		if (cp[0] == '/' && cp[1] == '*')
+		{
+			comment = 1;
+			cp[0] = cp[1] = 32;
 		}
-		if(cp[0]=='*' && cp[1]=='/') {
-			comment= 0;
-			cp[0]=cp[1]= 32;
+		if (cp[0] == '*' && cp[1] == '/')
+		{
+			comment = 0;
+			cp[0] = cp[1] = 32;
 		}
 
 		/* do not copy when: */
-		if(comment);
-		else if( cp[0]==' ' && cp[1]==' ' );
-		else if( cp[-1]=='*' && cp[0]==' ' );	/* pointers with a space */
-		else {
-			md[0]= cp[0];
+		if (comment)
+			;
+		else if (cp[0] == ' ' && cp[1] == ' ')
+			;
+		else if (cp[-1] == '*' && cp[0] == ' ')
+			; /* pointers with a space */
+		else
+		{
+			md[0] = cp[0];
 			md++;
 			newlen++;
 		}
 		cp++;
 	}
-	
+
 	free(temp);
 	return newlen;
 }
@@ -537,57 +574,58 @@ int preprocess_include(char *maindata, int len)
 static void *read_file_data(char *filename, int *len_r)
 {
 #ifdef WIN32
-	FILE *fp= fopen(filename, "rb");
+	FILE *fp = fopen(filename, "rb");
 #else
-	FILE *fp= fopen(filename, "r");
+	FILE *fp = fopen(filename, "r");
 #endif
 	void *data;
 
-	if (!fp) {
-		*len_r= -1;
+	if (!fp)
+	{
+		*len_r = -1;
 		return NULL;
 	}
 
 	fseek(fp, 0L, SEEK_END);
-	*len_r= ftell(fp);
+	*len_r = ftell(fp);
 	fseek(fp, 0L, SEEK_SET);
 
-	data= malloc_and_setzero(*len_r);
-	if (!data) {
-		*len_r= -1;
+	data = malloc_and_setzero(*len_r);
+	if (!data)
+	{
+		*len_r = -1;
 		fclose(fp);
 		return NULL;
 	}
 
-	if (fread(data, *len_r, 1, fp)!=1) {
-		*len_r= -1;
+	if (fread(data, *len_r, 1, fp) != 1)
+	{
+		*len_r = -1;
 		free(data);
 		fclose(fp);
 		return NULL;
 	}
-	
+
 	fclose(fp);
 	return data;
 }
 
+const char *skipStructTypes[] =
+	{
+		"btContactSolverInfoData",
+		"btRigidBodyConstructionInfo",
+		"Euler",
+		"btConstraintInfo2",
+		"btConstraintSetting",
+		"btTriangleInfo",
+		""};
 
-const char* skipStructTypes[]=
+int skipStruct(const char *structType)
 {
-	"btContactSolverInfoData",
-	"btRigidBodyConstructionInfo",
-	"Euler",
-	"btConstraintInfo2",
-	"btConstraintSetting",
-	"btTriangleInfo",
-		""
-};
-
-int	skipStruct(const char* structType)
-{
-	int i=0;
+	int i = 0;
 	while (strlen(skipStructTypes[i]))
 	{
-		if (strcmp(structType,skipStructTypes[i])==0)
+		if (strcmp(structType, skipStructTypes[i]) == 0)
 		{
 			return 1;
 		}
@@ -604,122 +642,128 @@ int convert_include(char *filename)
 	int filelen, count, overslaan, slen, type, name, strct;
 	short *structpoin, *sp;
 	char *maindata, *mainend, *md, *md1;
-	
-	md= maindata= (char*)read_file_data(filename, &filelen);
-	if (filelen==-1) {
+
+	md = maindata = (char *)read_file_data(filename, &filelen);
+	if (filelen == -1)
+	{
 		printf("Can't read file %s\n", filename);
 		return 1;
 	}
 
-	filelen= preprocess_include(maindata, filelen);
-	mainend= maindata+filelen-1;
+	filelen = preprocess_include(maindata, filelen);
+	mainend = maindata + filelen - 1;
 
 	/* we look for '{' and then back to 'struct' */
-	count= 0;
-	overslaan= 0;
-	while(count<filelen) {
-		
+	count = 0;
+	overslaan = 0;
+	while (count < filelen)
+	{
 		/* code for skipping a struct: two hashes on 2 lines. (preprocess added a space) */
-		if(md[0]=='#' && md[1]==' ' && md[2]=='#') {
-			overslaan= 1;
+		if (md[0] == '#' && md[1] == ' ' && md[2] == '#')
+		{
+			overslaan = 1;
 		}
-		
-		if(md[0]=='{') {
-			md[0]= 0;
-			if(overslaan) {
-				overslaan= 0;
-			}
-			else {
-				if(md[-1]==' ') md[-1]= 0;
-				md1= md-2;
-				while( *md1!=32) md1--;		/* to beginning of word */
-				md1++;
-				
-				/* we've got a struct name when... */
-				if( strncmp(md1-7, "struct", 6)==0 ) {
 
-					
+		if (md[0] == '{')
+		{
+			md[0] = 0;
+			if (overslaan)
+			{
+				overslaan = 0;
+			}
+			else
+			{
+				if (md[-1] == ' ') md[-1] = 0;
+				md1 = md - 2;
+				while (*md1 != 32) md1--; /* to beginning of word */
+				md1++;
+
+				/* we've got a struct name when... */
+				if (strncmp(md1 - 7, "struct", 6) == 0)
+				{
 					if (!skipStruct(md1))
 					{
-						strct= add_type(md1, 0);
-						structpoin= add_struct(strct);
-						sp= structpoin+2;
+						strct = add_type(md1, 0);
+						structpoin = add_struct(strct);
+						sp = structpoin + 2;
 
 						if (debugSDNA > 1) printf("\t|\t|-- detected struct %s\n", types[strct]);
 
 						/* first lets make it all nice strings */
-						md1= md+1;
-						while(*md1 != '}') {
-							if(md1>mainend) break;
-							
-							if(*md1==',' || *md1==' ') *md1= 0;
+						md1 = md + 1;
+						while (*md1 != '}')
+						{
+							if (md1 > mainend) break;
+
+							if (*md1 == ',' || *md1 == ' ') *md1 = 0;
 							md1++;
 						}
-						
+
 						/* read types and names until first character that is not '}' */
-						md1= md+1;
-						while( *md1 != '}' ) {
-							if(md1>mainend) break;
-							
+						md1 = md + 1;
+						while (*md1 != '}')
+						{
+							if (md1 > mainend) break;
+
 							/* skip when it says 'struct' or 'unsigned' or 'const' */
-							if(*md1) {
-								if( strncmp(md1, "struct", 6)==0 ) md1+= 7;
-								if( strncmp(md1, "unsigned", 8)==0 ) md1+= 9;
-								if( strncmp(md1, "const", 5)==0 ) md1+= 6;
-								
+							if (*md1)
+							{
+								if (strncmp(md1, "struct", 6) == 0) md1 += 7;
+								if (strncmp(md1, "unsigned", 8) == 0) md1 += 9;
+								if (strncmp(md1, "const", 5) == 0) md1 += 6;
+
 								/* we've got a type! */
-								type= add_type(md1, 0);
+								type = add_type(md1, 0);
 
 								if (debugSDNA > 1) printf("\t|\t|\tfound type %s (", md1);
 
-								md1+= strlen(md1);
+								md1 += strlen(md1);
 
-								
 								/* read until ';' */
-								while( *md1 != ';' ) {
-									if(md1>mainend) break;
-									
-									if(*md1) {
+								while (*md1 != ';')
+								{
+									if (md1 > mainend) break;
+
+									if (*md1)
+									{
 										/* We've got a name. slen needs
 										 * correction for function
 										 * pointers! */
-										slen= (int) strlen(md1);
-										if( md1[slen-1]==';' ) {
-											md1[slen-1]= 0;
+										slen = (int)strlen(md1);
+										if (md1[slen - 1] == ';')
+										{
+											md1[slen - 1] = 0;
 
-
-											name= add_name(md1);
+											name = add_name(md1);
 											slen += additional_slen_offset;
-											sp[0]= type;
-											sp[1]= name;
+											sp[0] = type;
+											sp[1] = name;
 
-											if ((debugSDNA>1) && (names[name] != 0 )) printf("%s |", names[name]);
+											if ((debugSDNA > 1) && (names[name] != 0)) printf("%s |", names[name]);
 
 											structpoin[1]++;
-											sp+= 2;
-																						
-											md1+= slen;
+											sp += 2;
+
+											md1 += slen;
 											break;
 										}
-										
 
-										name= add_name(md1);
+										name = add_name(md1);
 										slen += additional_slen_offset;
 
-										sp[0]= type;
-										sp[1]= name;
-										if ((debugSDNA > 1) && (names[name] != 0 )) printf("%s ||", names[name]);
+										sp[0] = type;
+										sp[1] = name;
+										if ((debugSDNA > 1) && (names[name] != 0)) printf("%s ||", names[name]);
 
 										structpoin[1]++;
-										sp+= 2;
-										
-										md1+= slen;
+										sp += 2;
+
+										md1 += slen;
 									}
 									md1++;
 								}
 
 								if (debugSDNA > 1) printf(")\n");
-
 							}
 							md1++;
 						}
@@ -730,7 +774,7 @@ int convert_include(char *filename)
 		count++;
 		md++;
 	}
-	
+
 	free(maindata);
 
 	return 0;
@@ -738,177 +782,205 @@ int convert_include(char *filename)
 
 int arraysize(char *astr, int len)
 {
-	int a, mul=1;
-	char str[100], *cp=0;
+	int a, mul = 1;
+	char str[100], *cp = 0;
 
-	memcpy(str, astr, len+1);
-	
-	for(a=0; a<len; a++) {
-		if( str[a]== '[' ) {
-			cp= &(str[a+1]);
+	memcpy(str, astr, len + 1);
+
+	for (a = 0; a < len; a++)
+	{
+		if (str[a] == '[')
+		{
+			cp = &(str[a + 1]);
 		}
-		else if( str[a]==']' && cp) {
-			str[a]= 0;
-			mul*= atoi(cp);
+		else if (str[a] == ']' && cp)
+		{
+			str[a] = 0;
+			mul *= atoi(cp);
 		}
 	}
-	
+
 	return mul;
 }
 
 static int calculate_structlens(int firststruct)
 {
-	int a, b, len, alphalen, unknown= nr_structs, lastunknown, structtype, type, mul, namelen;
+	int a, b, len, alphalen, unknown = nr_structs, lastunknown, structtype, type, mul, namelen;
 	short *sp, *structpoin;
 	char *cp;
 	int has_pointer, dna_error = 0;
-		
-	while(unknown) {
-		lastunknown= unknown;
-		unknown= 0;
-		
+
+	while (unknown)
+	{
+		lastunknown = unknown;
+		unknown = 0;
+
 		/* check all structs... */
-		for(a=0; a<nr_structs; a++) {
-			structpoin= structs[a];
-			structtype= structpoin[0];
+		for (a = 0; a < nr_structs; a++)
+		{
+			structpoin = structs[a];
+			structtype = structpoin[0];
 
 			/* when length is not known... */
-			if(typelens[structtype]==0) {
-				
-				sp= structpoin+2;
-				len= 0;
+			if (typelens[structtype] == 0)
+			{
+				sp = structpoin + 2;
+				len = 0;
 				alphalen = 0;
 				has_pointer = 0;
-				
+
 				/* check all elements in struct */
-				for(b=0; b<structpoin[1]; b++, sp+=2) {
-					type= sp[0];
-					cp= names[sp[1]];
-					
-					namelen= (int) strlen(cp);
+				for (b = 0; b < structpoin[1]; b++, sp += 2)
+				{
+					type = sp[0];
+					cp = names[sp[1]];
+
+					namelen = (int)strlen(cp);
 					/* is it a pointer or function pointer? */
-					if(cp[0]=='*' || cp[1]=='*') {
+					if (cp[0] == '*' || cp[1] == '*')
+					{
 						has_pointer = 1;
 						/* has the name an extra length? (array) */
-						mul= 1;
-						if( cp[namelen-1]==']') mul= arraysize(cp, namelen);
-						
+						mul = 1;
+						if (cp[namelen - 1] == ']') mul = arraysize(cp, namelen);
+
 						/* 4-8 aligned/ */
-						if(sizeof(void *) == 4) {
-							if (len % 4) {
+						if (sizeof(void *) == 4)
+						{
+							if (len % 4)
+							{
 								printf("Align pointer error in struct (len4): %s %s\n", types[structtype], cp);
 								dna_error = 1;
 							}
-						} else {
-							if (len % 8) {
+						}
+						else
+						{
+							if (len % 8)
+							{
 								printf("Align pointer error in struct (len8): %s %s\n", types[structtype], cp);
 								dna_error = 1;
 							}
 						}
 
-						if (alphalen % 8) {
-							printf("Align pointer error in struct (alphalen8): %s %s\n", types[structtype],cp);
+						if (alphalen % 8)
+						{
+							printf("Align pointer error in struct (alphalen8): %s %s\n", types[structtype], cp);
 							dna_error = 1;
 						}
 
 						len += sizeof(void *) * mul;
 						alphalen += 8 * mul;
-
-					} else if( typelens[type] ) {
+					}
+					else if (typelens[type])
+					{
 						/* has the name an extra length? (array) */
-						mul= 1;
-						if( cp[namelen-1]==']') mul= arraysize(cp, namelen);
-						
+						mul = 1;
+						if (cp[namelen - 1] == ']') mul = arraysize(cp, namelen);
+
 						/* struct alignment */
-						if(type >= firststruct) {
-							if(sizeof(void *)==8 && (len % 8) ) {
-								printf("Align struct error: %s %s\n", types[structtype],cp);
+						if (type >= firststruct)
+						{
+							if (sizeof(void *) == 8 && (len % 8))
+							{
+								printf("Align struct error: %s %s\n", types[structtype], cp);
 								dna_error = 1;
 							}
 						}
-						
+
 						/* 2-4 aligned/ */
-						if(typelens[type]>3 && (len % 4) ) {
-							printf("Align 4 error in struct: %s %s (add %d padding bytes)\n", types[structtype], cp, len%4);
+						if (typelens[type] > 3 && (len % 4))
+						{
+							printf("Align 4 error in struct: %s %s (add %d padding bytes)\n", types[structtype], cp, len % 4);
 							dna_error = 1;
 						}
-						else if(typelens[type]==2 && (len % 2) ) {
-							printf("Align 2 error in struct: %s %s (add %d padding bytes)\n", types[structtype], cp, len%2);
+						else if (typelens[type] == 2 && (len % 2))
+						{
+							printf("Align 2 error in struct: %s %s (add %d padding bytes)\n", types[structtype], cp, len % 2);
 							dna_error = 1;
 						}
 
-						len += mul*typelens[type];
+						len += mul * typelens[type];
 						alphalen += mul * alphalens[type];
-						
-					} else {
-						len= 0;
+					}
+					else
+					{
+						len = 0;
 						alphalen = 0;
 						break;
 					}
 				}
-				
-				if (len==0) {
+
+				if (len == 0)
+				{
 					unknown++;
-				} else {
-					typelens[structtype]= len;
-					alphalens[structtype]= alphalen;
+				}
+				else
+				{
+					typelens[structtype] = len;
+					alphalens[structtype] = alphalen;
 					// two ways to detect if a struct contains a pointer:
 					// has_pointer is set or alphalen != len
-					if (has_pointer || alphalen != len) {
-						if (alphalen % 8) {
-							printf("alphalen = %d len = %d\n",alphalen,len);
-							printf("Sizeerror 8 in struct: %s (add %d bytes)\n", types[structtype], alphalen%8);
+					if (has_pointer || alphalen != len)
+					{
+						if (alphalen % 8)
+						{
+							printf("alphalen = %d len = %d\n", alphalen, len);
+							printf("Sizeerror 8 in struct: %s (add %d bytes)\n", types[structtype], alphalen % 8);
 							dna_error = 1;
 						}
 					}
-					
-					if(len % 4) {
-						printf("Sizeerror 4 in struct: %s (add %d bytes)\n", types[structtype], len%4);
+
+					if (len % 4)
+					{
+						printf("Sizeerror 4 in struct: %s (add %d bytes)\n", types[structtype], len % 4);
 						dna_error = 1;
 					}
-					
 				}
 			}
 		}
-		
-		if(unknown==lastunknown) break;
+
+		if (unknown == lastunknown) break;
 	}
-	
-	if(unknown) {
+
+	if (unknown)
+	{
 		printf("ERROR: still %d structs unknown\n", unknown);
 
-		if (debugSDNA) {
+		if (debugSDNA)
+		{
 			printf("*** Known structs : \n");
-			
-			for(a=0; a<nr_structs; a++) {
-				structpoin= structs[a];
-				structtype= structpoin[0];
-				
+
+			for (a = 0; a < nr_structs; a++)
+			{
+				structpoin = structs[a];
+				structtype = structpoin[0];
+
 				/* length unknown */
-				if(typelens[structtype]!=0) {
+				if (typelens[structtype] != 0)
+				{
 					printf("  %s\n", types[structtype]);
 				}
 			}
 		}
 
-			
 		printf("*** Unknown structs : \n");
-			
-		for(a=0; a<nr_structs; a++) {
-			structpoin= structs[a];
-			structtype= structpoin[0];
+
+		for (a = 0; a < nr_structs; a++)
+		{
+			structpoin = structs[a];
+			structtype = structpoin[0];
 
 			/* length unkown yet */
-			if(typelens[structtype]==0) {
+			if (typelens[structtype] == 0)
+			{
 				printf("  %s\n", types[structtype]);
 			}
 		}
 	}
 
-	return(dna_error);
+	return (dna_error);
 }
 
-
 #define MAX_DNA_LINE_LENGTH 20
 
 void dna_write(FILE *file, void *pntr, int size)
@@ -917,13 +989,14 @@ void dna_write(FILE *file, void *pntr, int size)
 	int i;
 	char *data;
 
-	data = (char *) pntr;
-	
-	for (i = 0 ; i < size ; i++)
+	data = (char *)pntr;
+
+	for (i = 0; i < size; i++)
 	{
 		fprintf(file, "char(%d),", data[i]);
 		linelength++;
-		if (linelength >= MAX_DNA_LINE_LENGTH) {
+		if (linelength >= MAX_DNA_LINE_LENGTH)
+		{
 			fprintf(file, "\n");
 			linelength = 0;
 		}
@@ -932,27 +1005,27 @@ void dna_write(FILE *file, void *pntr, int size)
 
 void printStructLenghts(void)
 {
-	int a, unknown= nr_structs, lastunknown, structtype;
+	int a, unknown = nr_structs, lastunknown, structtype;
 	short *structpoin;
 	printf("\n\n*** All detected structs:\n");
 
-	while(unknown) {
-		lastunknown= unknown;
-		unknown= 0;
-		
+	while (unknown)
+	{
+		lastunknown = unknown;
+		unknown = 0;
+
 		/* check all structs... */
-		for(a=0; a<nr_structs; a++) {
-			structpoin= structs[a];
-			structtype= structpoin[0];
+		for (a = 0; a < nr_structs; a++)
+		{
+			structpoin = structs[a];
+			structtype = structpoin[0];
 			printf("\t%s\t:%d\n", types[structtype], typelens[structtype]);
 		}
 	}
 
 	printf("*** End of list\n");
-
 }
 
-
 int make_structDNA(char *baseDirectory, FILE *file)
 {
 	int len, i;
@@ -961,87 +1034,93 @@ int make_structDNA(char *baseDirectory, FILE *file)
 	/* it a bit. Hope this is enough :) -nzc-                                */
 	char str[SDNA_MAX_FILENAME_LENGTH], *cp;
 	int firststruct;
-	
-	if (debugSDNA > -1) {
+
+	if (debugSDNA > -1)
+	{
 		fflush(stdout);
 		printf("Running makesdna at debug level %d\n", debugSDNA);
-		
 	}
-		
+
 	/* the longest known struct is 50k, so we assume 100k is sufficent! */
-	namedata= (char*)malloc_and_setzero(maxdata);
-	typedata= (char*)malloc_and_setzero(maxdata);
-	structdata= (short*)malloc_and_setzero(maxdata);
-	
+	namedata = (char *)malloc_and_setzero(maxdata);
+	typedata = (char *)malloc_and_setzero(maxdata);
+	structdata = (short *)malloc_and_setzero(maxdata);
+
 	/* a maximum of 5000 variables, must be sufficient? */
-	names= (char**)malloc_and_setzero(sizeof(char *)*maxnr);
-	types= (char**)malloc_and_setzero(sizeof(char *)*maxnr);
-	typelens= (short*) malloc_and_setzero(sizeof(short)*maxnr);
-	alphalens= (short*)malloc_and_setzero(sizeof(short)*maxnr);
-	structs= (short**)malloc_and_setzero(sizeof(short)*maxnr);
+	names = (char **)malloc_and_setzero(sizeof(char *) * maxnr);
+	types = (char **)malloc_and_setzero(sizeof(char *) * maxnr);
+	typelens = (short *)malloc_and_setzero(sizeof(short) * maxnr);
+	alphalens = (short *)malloc_and_setzero(sizeof(short) * maxnr);
+	structs = (short **)malloc_and_setzero(sizeof(short) * maxnr);
 
 	/* insertion of all known types */
 	/* watch it: uint is not allowed! use in structs an unsigned int */
-	add_type("char", 1);	/* 0 */
-	add_type("uchar", 1);	/* 1 */
-	add_type("short", 2);	/* 2 */
-	add_type("ushort", 2);	/* 3 */
-	add_type("int", 4);		/* 4 */
-	add_type("long", 4);	/* 5 */		/* should it be 8 on 64 bits? */
-	add_type("ulong", 4);	/* 6 */
-	add_type("float", 4);	/* 7 */
-	add_type("double", 8);	/* 8 */
-	add_type("void", 0);	/* 9 */
+	add_type("char", 1);         /* 0 */
+	add_type("uchar", 1);        /* 1 */
+	add_type("short", 2);        /* 2 */
+	add_type("ushort", 2);       /* 3 */
+	add_type("int", 4);          /* 4 */
+	add_type("long", 4); /* 5 */ /* should it be 8 on 64 bits? */
+	add_type("ulong", 4);        /* 6 */
+	add_type("float", 4);        /* 7 */
+	add_type("double", 8);       /* 8 */
+	add_type("void", 0);         /* 9 */
 
 	// the defines above shouldn't be output in the padding file...
 	firststruct = nr_types;
-	
+
 	/* add all include files defined in the global array                     */
 	/* Since the internal file+path name buffer has limited length, I do a   */
 	/* little test first...                                                  */
 	/* Mind the breaking condition here!                                     */
-	if (debugSDNA) printf("\tStart of header scan:\n"); 
-	for (i = 0; strlen(includefiles[i]); i++) {
+	if (debugSDNA) printf("\tStart of header scan:\n");
+	for (i = 0; strlen(includefiles[i]); i++)
+	{
 		sprintf(str, "%s%s", baseDirectory, includefiles[i]);
-  		if (debugSDNA) printf("\t|-- Converting %s\n", str); 
-		if (convert_include(str)) {
+		if (debugSDNA) printf("\t|-- Converting %s\n", str);
+		if (convert_include(str))
+		{
 			return (1);
 		}
 	}
-	if (debugSDNA) printf("\tFinished scanning %d headers.\n", i); 
+	if (debugSDNA) printf("\tFinished scanning %d headers.\n", i);
 
-	if (calculate_structlens(firststruct)) {
+	if (calculate_structlens(firststruct))
+	{
 		// error
-		return(1);
+		return (1);
 	}
 
-
 	/* FOR DEBUG */
 	if (debugSDNA > 1)
 	{
-		int a,b;
-/*  		short *elem; */
+		int a, b;
+		/*  		short *elem; */
 		short num_types;
 
 		printf("nr_names %d nr_types %d nr_structs %d\n", nr_names, nr_types, nr_structs);
-		for(a=0; a<nr_names; a++) { 
+		for (a = 0; a < nr_names; a++)
+		{
 			printf(" %s \n", names[a]);
 		}
 		printf("\n");
-		
-		sp= typelens;
-		for(a=0; a<nr_types; a++, sp++) { 
+
+		sp = typelens;
+		for (a = 0; a < nr_types; a++, sp++)
+		{
 			printf(" %s %d\n", types[a], *sp);
 		}
 		printf("\n");
-		
-		for(a=0; a<nr_structs; a++) {
-			sp= structs[a];
-			printf(" struct %s elems: %d size: %d\n", types[sp[0]], sp[1],typelens[sp[0]]);
-			num_types  = sp[1];
-			sp+= 2;
+
+		for (a = 0; a < nr_structs; a++)
+		{
+			sp = structs[a];
+			printf(" struct %s elems: %d size: %d\n", types[sp[0]], sp[1], typelens[sp[0]]);
+			num_types = sp[1];
+			sp += 2;
 			/* ? num_types was elem? */
-			for(b=0; b< num_types; b++, sp+= 2) {
+			for (b = 0; b < num_types; b++, sp += 2)
+			{
 				printf("   %s %s\n", types[sp[0]], names[sp[1]]);
 			}
 		}
@@ -1050,80 +1129,87 @@ int make_structDNA(char *baseDirectory, FILE *file)
 	/* file writing */
 
 	if (debugSDNA > -1) printf("Writing file ... ");
-		
-	if(nr_names==0 || nr_structs==0);
-	else {
+
+	if (nr_names == 0 || nr_structs == 0)
+		;
+	else
+	{
 		strcpy(str, "SDNA");
 		dna_write(file, str, 4);
-		
+
 		/* write names */
 		strcpy(str, "NAME");
 		dna_write(file, str, 4);
-		len= nr_names;
+		len = nr_names;
 		dna_write(file, &len, 4);
-		
+
 		/* calculate size of datablock with strings */
-		cp= names[nr_names-1];
-		cp+= strlen(names[nr_names-1]) + 1;			/* +1: null-terminator */
-		len= (btintptr_t) (cp - (char*) names[0]);
-		len= (len+3) & ~3;
+		cp = names[nr_names - 1];
+		cp += strlen(names[nr_names - 1]) + 1; /* +1: null-terminator */
+		len = (btintptr_t)(cp - (char *)names[0]);
+		len = (len + 3) & ~3;
 		dna_write(file, names[0], len);
-		
+
 		/* write TYPES */
 		strcpy(str, "TYPE");
 		dna_write(file, str, 4);
-		len= nr_types;
+		len = nr_types;
 		dna_write(file, &len, 4);
-	
+
 		/* calculate datablock size */
-		cp= types[nr_types-1];
-		cp+= strlen(types[nr_types-1]) + 1;		/* +1: null-terminator */
-		len= (btintptr_t) (cp - (char*) types[0]);
-		len= (len+3) & ~3;
-		
+		cp = types[nr_types - 1];
+		cp += strlen(types[nr_types - 1]) + 1; /* +1: null-terminator */
+		len = (btintptr_t)(cp - (char *)types[0]);
+		len = (len + 3) & ~3;
+
 		dna_write(file, types[0], len);
-		
+
 		/* WRITE TYPELENGTHS */
 		strcpy(str, "TLEN");
 		dna_write(file, str, 4);
-		
-		len= 2*nr_types;
-		if(nr_types & 1) len+= 2;
+
+		len = 2 * nr_types;
+		if (nr_types & 1) len += 2;
 		dna_write(file, typelens, len);
-		
+
 		/* WRITE STRUCTS */
 		strcpy(str, "STRC");
 		dna_write(file, str, 4);
-		len= nr_structs;
+		len = nr_structs;
 		dna_write(file, &len, 4);
-	
+
 		/* calc datablock size */
-		sp= structs[nr_structs-1];
-		sp+= 2+ 2*( sp[1] );
-		len= (btintptr_t) ((char*) sp - (char*) structs[0]);
-		len= (len+3) & ~3;
-		
+		sp = structs[nr_structs - 1];
+		sp += 2 + 2 * (sp[1]);
+		len = (btintptr_t)((char *)sp - (char *)structs[0]);
+		len = (len + 3) & ~3;
+
 		dna_write(file, structs[0], len);
-	
+
 		/* a simple dna padding test */
-		if (0) {
+		if (0)
+		{
 			FILE *fp;
 			int a;
-			
-			fp= fopen("padding.c", "w");
-			if(fp==NULL);
-			else {
 
+			fp = fopen("padding.c", "w");
+			if (fp == NULL)
+				;
+			else
+			{
 				// add all include files defined in the global array
-				for (i = 0; strlen(includefiles[i]); i++) {
+				for (i = 0; strlen(includefiles[i]); i++)
+				{
 					fprintf(fp, "#include \"%s%s\"\n", baseDirectory, includefiles[i]);
 				}
 
 				fprintf(fp, "main(){\n");
 				sp = typelens;
 				sp += firststruct;
-				for(a=firststruct; a<nr_types; a++, sp++) { 
-					if(*sp) {
+				for (a = firststruct; a < nr_types; a++, sp++)
+				{
+					if (*sp)
+					{
 						fprintf(fp, "\tif(sizeof(struct %s) - %d) printf(\"ALIGN ERROR:", types[a], *sp);
 						fprintf(fp, "%%d %s %d ", types[a], *sp);
 						fprintf(fp, "\\n\",  sizeof(struct %s) - %d);\n", types[a], *sp);
@@ -1135,8 +1221,7 @@ int make_structDNA(char *baseDirectory, FILE *file)
 		}
 		/*	end end padding test */
 	}
-	
-	
+
 	free(namedata);
 	free(typedata);
 	free(structdata);
@@ -1146,15 +1231,15 @@ int make_structDNA(char *baseDirectory, FILE *file)
 	free(structs);
 
 	if (debugSDNA > -1) printf("done.\n");
-	
-	return(0);
+
+	return (0);
 }
 
 /* ************************* END MAKE DNA ********************** */
 
 static void make_bad_file(char *file)
 {
-	FILE *fp= fopen(file, "w");
+	FILE *fp = fopen(file, "w");
 	fprintf(fp, "ERROR! Cannot make correct DNA.c file, STUPID!\n");
 	fclose(fp);
 }
@@ -1163,18 +1248,18 @@ static void make_bad_file(char *file)
 #define BASE_HEADER "../"
 #endif
 
-int main(int argc, char ** argv)
+int main(int argc, char **argv)
 {
-//	printf("btCollisionObject=%d\n",sizeof(btCollisionObject));
-//	printf("btCollisionObjectData=%d\n",sizeof(btCollisionObjectData));
-//	printf("btTransform=%d\n",sizeof(btTransform));
-//	printf("btTransformData=%d\n",sizeof(btTransformData));
-//
-//	btCollisionObject* bla = new btCollisionObject();
-//	btCollisionObjectData* bla2 = new btCollisionObjectData();
+	//	printf("btCollisionObject=%d\n",sizeof(btCollisionObject));
+	//	printf("btCollisionObjectData=%d\n",sizeof(btCollisionObjectData));
+	//	printf("btTransform=%d\n",sizeof(btTransform));
+	//	printf("btTransformData=%d\n",sizeof(btTransformData));
+	//
+	//	btCollisionObject* bla = new btCollisionObject();
+	//	btCollisionObjectData* bla2 = new btCollisionObjectData();
 
 	//int offsetof(bla,m_hasAnisotropicFriction);
-/*
+	/*
 	btTransformData	m_worldTransform;
 	btTransform	m_interpolationWorldTransform;
 	btVector3	m_interpolationLinearVelocity;
@@ -1204,54 +1289,66 @@ int main(int argc, char ** argv)
 	FILE *file;
 	int return_status = 0;
 
-	if (argc!=2 && argc!=3) {
+	if (argc != 2 && argc != 3)
+	{
 		printf("Usage: %s outfile.c [base directory]\n", argv[0]);
 		return_status = 1;
-	} else {
+	}
+	else
+	{
 		file = fopen(argv[1], "w");
-		if (!file) {
-			printf ("Unable to open file: %s\n", argv[1]);
+		if (!file)
+		{
+			printf("Unable to open file: %s\n", argv[1]);
 			return_status = 1;
-		} else {
+		}
+		else
+		{
 			char baseDirectory[256];
 
-			if (argc==3) {
+			if (argc == 3)
+			{
 				strcpy(baseDirectory, argv[2]);
-			} else {
+			}
+			else
+			{
 				strcpy(baseDirectory, BASE_HEADER);
 			}
 
-			if (sizeof(void*)==8)
+			if (sizeof(void *) == 8)
 			{
-				fprintf (file, "char sBulletDNAstr64[]= {\n");
-			} else
+				fprintf(file, "char sBulletDNAstr64[]= {\n");
+			}
+			else
 			{
-				fprintf (file, "char sBulletDNAstr[]= {\n");
+				fprintf(file, "char sBulletDNAstr[]= {\n");
 			}
 
-			if (make_structDNA(baseDirectory, file)) {
+			if (make_structDNA(baseDirectory, file))
+			{
 				// error
 				fclose(file);
 				make_bad_file(argv[1]);
 				return_status = 1;
-			} else {
+			}
+			else
+			{
 				fprintf(file, "};\n");
-				if (sizeof(void*)==8)
+				if (sizeof(void *) == 8)
 				{
 					fprintf(file, "int sBulletDNAlen64= sizeof(sBulletDNAstr64);\n");
-				} else
+				}
+				else
 				{
 					fprintf(file, "int sBulletDNAlen= sizeof(sBulletDNAstr);\n");
 				}
-	
+
 				fclose(file);
 			}
 		}
 	}
 
-		
-	return(return_status);
+	return (return_status);
 }
 
-
 /* end of list */
