@@ -8,6 +8,9 @@
 		".."
 	}		
 	
+    if os.is("Linux") then
+        buildoptions{"-fPIC"}
+    end
 
 	files {
 		"**.cpp",
