@@ -9,6 +9,9 @@ function createProject(vendor)
 			
 		kind "StaticLib"
 		
+        if os.is("Linux") then
+            buildoptions{"-fPIC"}
+        end
 		
 		includedirs {
 			".",".."
