@@ -5,6 +5,10 @@
 	includedirs {
 		"../../../src"
 	}
+	
+    if os.is("Linux") then
+        buildoptions{"-fPIC"}
+    end
 	 
 	files {
 		"**.cpp",
