@@ -1,6 +1,6 @@
 /*
 Bullet Continuous Collision Detection and Physics Library
-Copyright (c) 2003-2006 Erwin Coumans  http://continuousphysics.com/Bullet/
+Copyright (c) 2003-2006 Erwin Coumans  https://bulletphysics.org
 
 This software is provided 'as-is', without any express or implied warranty.
 In no event will the authors be held liable for any damages arising from the use of this software.
@@ -14,6 +14,7 @@ subject to the following restrictions:
 */
 
 #include "btAlignedAllocator.h"
+#include <string.h>
 
 #ifdef BT_DEBUG_MEMORY_ALLOCATIONS
 int gNumAlignedAllocs = 0;
@@ -23,7 +24,9 @@ int gTotalBytesAlignedAllocs = 0;  //detect memory leaks
 
 static void *btAllocDefault(size_t size)
 {
-	return malloc(size);
+  char* data = (char*) malloc(size);
+  memset(data,0,size);//keep msan happy
+  return data;
 }
 
 static void btFreeDefault(void *ptr)
@@ -73,6 +76,8 @@ static inline void *btAlignedAllocDefault(size_t size, int alignment)
 	{
 		ret = (void *)(real);
 	}
+  //keep msan happy
+  memset((char*) ret, 0, size);
 	return (ret);
 }
 
