@@ -9,18 +9,18 @@
 #define BulletTest_TestList_h
 
 #ifdef __cplusplus
-extern "C" { 
+extern "C"
+{
 #endif
 
-    
-typedef struct TestDesc
-{
-    const char *name;
-    int (*test_func)(void);     // return 0 for success, non-zero for failure
-}TestDesc;
+	typedef struct TestDesc
+	{
+		const char *name;
+		int (*test_func)(void);  // return 0 for success, non-zero for failure
+	} TestDesc;
+
+	extern TestDesc gTestList[];
 
-extern TestDesc  gTestList[];
-    
 #ifdef __cplusplus
 }
 #endif
