@@ -9,14 +9,14 @@
 #define BulletTest_Test_3x3transpose_h
 
 #ifdef __cplusplus
-extern "C" { 
+extern "C"
+{
 #endif
-    
-    int Test_3x3transpose(void);
-    
+
+	int Test_3x3transpose(void);
+
 #ifdef __cplusplus
 }
 #endif
 
-
 #endif
