@@ -4,8 +4,8 @@
 #include <string.h>
 #include <enet/enet.h>
 
-
-int main(int argc, char* argv[]) {
+int main(int argc, char *argv[])
+{
 	ENetHost *client;
 	ENetAddress address;
 	ENetPeer *peer;
@@ -15,42 +15,41 @@ int main(int argc, char* argv[]) {
 
 	puts("Starting client");
 
-	if (enet_initialize() != 0) {
+	if (enet_initialize() != 0)
+	{
 		fprintf(stderr, "Error initialising enet");
 		exit(EXIT_FAILURE);
-
 	}
 
-	client = enet_host_create(NULL, /* create a client host */
-		1,    /* number of clients */
-		2,    /* number of channels */
-		57600 / 8,    /* incoming bandwith */
-		14400 / 8);   /* outgoing bandwith */
+	client = enet_host_create(NULL,       /* create a client host */
+							  1,          /* number of clients */
+							  2,          /* number of channels */
+							  57600 / 8,  /* incoming bandwith */
+							  14400 / 8); /* outgoing bandwith */
 
-	if (client == NULL) {
+	if (client == NULL)
+	{
 		fprintf(stderr, "Could not create client host");
 		exit(EXIT_FAILURE);
-
 	}
 
-
 	enet_address_set_host(&address, "localhost");
 	address.port = 1234;
 
 	peer = enet_host_connect(client,
-		&address,    /* address to connect to */
-		2,           /* number of channels */
-		0);          /* user data supplied to
+							 &address, /* address to connect to */
+							 2,        /* number of channels */
+							 0);       /* user data supplied to
 						  the receiving host */
 
-	if (peer == NULL) {
-		fprintf(stderr, "No available peers for initiating an ENet "
-			"connection.\n");
+	if (peer == NULL)
+	{
+		fprintf(stderr,
+				"No available peers for initiating an ENet "
+				"connection.\n");
 		exit(EXIT_FAILURE);
-
 	}
 
-
 	/* Try to connect to server within 5 seconds */
 	if (enet_host_service(client, &event, 5000) > 0 &&
 		event.type == ENET_EVENT_TYPE_CONNECT)
@@ -81,32 +80,33 @@ int main(int argc, char* argv[]) {
 			{
 				switch (event.type)
 				{
-				case ENET_EVENT_TYPE_CONNECT:
-					printf("A new client connected from %x:%u.\n",
-						event.peer->address.host,
-						event.peer->address.port);
+					case ENET_EVENT_TYPE_CONNECT:
+						printf("A new client connected from %x:%u.\n",
+							   event.peer->address.host,
+							   event.peer->address.port);
 
-					event.peer->data = (void*)"New User";
-					break;
+						event.peer->data = (void *)"New User";
+						break;
 
-				case ENET_EVENT_TYPE_RECEIVE:
-					printf("A packet of length %u containing '%s' was "
-						"received from %s on channel %u.\n",
-						event.packet->dataLength,
-						event.packet->data,
-						event.peer->data,
-						event.channelID);
+					case ENET_EVENT_TYPE_RECEIVE:
+						printf(
+							"A packet of length %u containing '%s' was "
+							"received from %s on channel %u.\n",
+							event.packet->dataLength,
+							event.packet->data,
+							event.peer->data,
+							event.channelID);
 
-					/* Clean up the packet now that we're done using it.
+						/* Clean up the packet now that we're done using it.
 						> */
-					enet_packet_destroy(event.packet);
+						enet_packet_destroy(event.packet);
 
-					break;
+						break;
 
-				case ENET_EVENT_TYPE_DISCONNECT:
-					printf("%s disconnected.\n", event.peer->data);
+					case ENET_EVENT_TYPE_DISCONNECT:
+						printf("%s disconnected.\n", event.peer->data);
 
-					break;
+						break;
 				}
 			}
 			else if (serviceResult > 0)
@@ -114,29 +114,25 @@ int main(int argc, char* argv[]) {
 				puts("Error with servicing the client");
 				exit(EXIT_FAILURE);
 			}
-
 		}
 
-
 		printf("Say> ");
 #ifdef _WIN32
 		gets_s(message, 1024);
 #else
-		fgets(message,1024,stdin);
+		fgets(message, 1024, stdin);
 #endif
 		if (strcmp(message, "exit") == 0 ||
-			strcmp(message, "quit") == 0) {
+			strcmp(message, "quit") == 0)
+		{
 			break;
-
 		}
 
-		if (strlen(message) > 0) {
-			ENetPacket *packet = enet_packet_create(message, strlen
-			(message) + 1, ENET_PACKET_FLAG_RELIABLE);
+		if (strlen(message) > 0)
+		{
+			ENetPacket *packet = enet_packet_create(message, strlen(message) + 1, ENET_PACKET_FLAG_RELIABLE);
 			enet_peer_send(peer, 0, packet);
-
 		}
-
 	}
 
 	enet_peer_disconnect(peer, 0);
@@ -145,24 +141,20 @@ int main(int argc, char* argv[]) {
 	/* and drop any packets received packets */
 	while (enet_host_service(client, &event, 3000) > 0)
 	{
-
 		switch (event.type)
 		{
-		case ENET_EVENT_TYPE_RECEIVE:
-			enet_packet_destroy(event.packet);
-			break;
+			case ENET_EVENT_TYPE_RECEIVE:
+				enet_packet_destroy(event.packet);
+				break;
 
-		case ENET_EVENT_TYPE_DISCONNECT:
-			puts("Disconnection succeeded.");
-			break;
+			case ENET_EVENT_TYPE_DISCONNECT:
+				puts("Disconnection succeeded.");
+				break;
 		}
 	}
 
-
 	enet_host_destroy(client);
 	enet_deinitialize();
 
 	return 0;
-
-
 }
