@@ -11,8 +11,12 @@
 		defines {"_VARIADIC_MAX=10"}
 	end
 	
-	--targetdir "../../lib"	
+	
 
 	includedirs {
 		".","include"
 	}
+    if os.is("Linux") then
+        buildoptions{"-fPIC"}
+    end
+	
\ No newline at end of file
